==> abacus-instrumentation-client-1.0.0.tgz: package/index.js <==
/* eslint-disable prefer-arrow-callback */
const request = require('superagent')
const merge = require('lodash.merge')

function createOnEnd (res, rej, payload) {
  payload = payload || { }

  return function onEnd (err, resp) {
    if (err || !resp.ok) {
      rej(err)
    } else {
      if (resp.body && resp.body.rows)
        res(resp.body.rows.map(function (r) {
          return r && r.value ? r.value : r
        }))
      else
        res(merge({ }, resp.body, payload))
    }
  }
}

const Client = { }

Client.createClient = function (name, options) {
  options = options || { }

  const auth = options.auth || [ 'admin', 'Movie*123' ]
  const baseURL = options.baseURL || 'http://deacouchdb.dynprod.netflix.net:5984'
  const contentType = 'application/json charset=utf-8'
  const dbName = options.dbName || 'instrumentation'
  const version = options.version || '*'

  const client = { }

  function mergePayload (payload) {
    return merge({ }, {
      'abacus-app-version' : version,
      'abacus-app-name'    : name
    }, payload)
  }


  // Create an instrumentation entry
  client.create = function (payload) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej, payload)
      return request
        .post(baseURL + '/' + dbName)
        .accept('json')
        .send(mergePayload(payload))
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // Restart
  client.restart = function () {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .post(baseURL + '/_restart')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }

  // Create instrumentation entry w/ specific identifier
  client.createWithID = function (id, payload) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej, payload)
      return request
        .put(baseURL + '/' + dbName + '/' + id)
        .accept('json')
        .send(mergePayload(payload))
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // View instrumentation entry
  client.showOne = function (id) {
    if (!id) {
      throw new Error('`showOne` requires a document id')
      return
    }

    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/' + id)
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // View instrumentation db info
  client.showDB = function () {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName)
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // Get instrumentation entries by app name
  client.showViaApp = function (appName) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/_design/index/_view/app')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .query({
          startkey : '"' + appName + '"'
        })
        .redirects(0)
        .end(onEnd)
    })
  }


  // Get instrumentation entries by app name and email addy
  client.showViaAppAndEmail = function (appName, email) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/_design/index/_view/app-email')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .query({
          startkey : '["' + appName + '", "' + email + '"]'
        })
        .redirects(0)
        .end(onEnd)
    })
  }


  // Get instrumentation entries by app name and full name
  client.showViaAppAndFullName = function (appName, fullName) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/_design/index/_view/app-fullname')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .query({
          startkey : '["' + appName + '", "' + fullName + '"]'
        })
        .redirects(0)
        .end(onEnd)
    })
  }


  return client
}

module.exports = Client

==> abacus-instrumentation-client-1.0.3.tgz: package/index.js <==
/* eslint-disable prefer-arrow-callback */
const request = require('superagent')
const merge = require('lodash.merge')

const createOnEnd = function createOnEnd (res, rej, payload) {
  payload = payload || { }

  return function onEnd (err, resp) {
    if (err || !resp.ok) {
      rej(err)
    } else {
      if (resp.body && resp.body.rows)
        res(resp.body.rows.map(function (r) {
          return r && r.value ? r.value : r
        }))
      else
        res(merge({ }, resp.body, payload))
    }
  }
}

const Client = { }

Client.createClient = function (name, options) {
  options = options || { }

  const auth = options.auth || [ 'admin', 'Movie*123' ]
  const baseURL = options.baseURL || 'http://deacouchdb.dynprod.netflix.net'
  const contentType = 'application/json charset=utf-8'
  const dbName = options.dbName || 'instrumentation'
  const version = options.version || '*'

  const client = { }

  function mergePayload (payload) {
    return merge({ }, {
      'abacus-app-version' : version,
      'abacus-app-name'    : name
    }, payload)
  }


  // Create an instrumentation entry
  client.create = function (payload) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej, payload)
      return request
        .post(baseURL + '/' + dbName)
        .accept('json')
        .send(mergePayload(payload))
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // Restart
  client.restart = function () {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .post(baseURL + '/_restart')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }

  // Create instrumentation entry w/ specific identifier
  client.createWithID = function (id, payload) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej, payload)
      return request
        .put(baseURL + '/' + dbName + '/' + id)
        .accept('json')
        .send(mergePayload(payload))
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // View instrumentation entry
  client.showOne = function (id) {
    if (!id) {
      throw new Error('`showOne` requires a document id')
      return
    }

    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/' + id)
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // View instrumentation db info
  client.showDB = function () {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName)
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .redirects(0)
        .end(onEnd)
    })
  }


  // Get instrumentation entries by app name
  client.showViaApp = function (appName) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/_design/index/_view/app')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .query({
          startkey : '"' + appName + '"',
          endkey   : '"' + appName + '"'
        })
        .redirects(0)
        .end(onEnd)
    })
  }


  // Get instrumentation entries by app name and email addy
  client.showViaAppAndEmail = function (appName, email) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/_design/index/_view/app-email')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .query({
          startkey : '["' + appName + '", "' + email + '"]',
          endkey : '["' + appName + '", "' + email + '"]'
        })
        .redirects(0)
        .end(onEnd)
    })
  }


  // Get instrumentation entries by app name and full name
  client.showViaAppAndFullName = function (appName, fullName) {
    return new Promise(function (res, rej) {
      const onEnd = createOnEnd(res, rej)
      return request
        .get(baseURL + '/' + dbName + '/_design/index/_view/app-fullname')
        .accept('json')
        .auth(auth[0], auth[1])
        .set('Content-Type', contentType)
        .query({
          startkey : '["' + appName + '", "' + fullName + '"]',
          endkey   : '["' + appName + '", "' + fullName + '"]'
        })
        .redirects(0)
        .end(onEnd)
    })
  }


  return client
}

module.exports = Client
